print("import: u'socketio'")
import socketio

print("import: u'socketio.base_manager'")
import socketio.base_manager

print("import: u'socketio.kombu_manager'")
import socketio.kombu_manager

print("import: u'socketio.middleware'")
import socketio.middleware

print("import: u'socketio.namespace'")
import socketio.namespace

print("import: u'socketio.packet'")
import socketio.packet

print("import: u'socketio.pubsub_manager'")
import socketio.pubsub_manager

print("import: u'socketio.redis_manager'")
import socketio.redis_manager

print("import: u'socketio.server'")
import socketio.server




import sys

from .middleware import Middleware
from .base_manager import BaseManager
from .pubsub_manager import PubSubManager
from .kombu_manager import KombuManager
from .redis_manager import RedisManager
from .zmq_manager import ZmqManager
from .server import Server
from .namespace import Namespace
if sys.version_info >= (3, 5):  # pragma: no cover
    from .asyncio_server import AsyncServer
    from .asyncio_manager import AsyncManager
    from .asyncio_namespace import AsyncNamespace
    from .asyncio_redis_manager import AsyncRedisManager
else:  # pragma: no cover
    AsyncServer = None
    AsyncManager = None
    AsyncNamespace = None
    AsyncRedisManager = None

__version__ = '1.9.0'

__all__ = ['__version__', 'Middleware', 'Server', 'BaseManager',
           'PubSubManager', 'KombuManager', 'RedisManager', 'ZmqManager',
           'Namespace']
if AsyncServer is not None:  # pragma: no cover
    __all__ += ['AsyncServer', 'AsyncNamespace', 'AsyncManager',
                'AsyncRedisManager']



import engineio


class Middleware(engineio.Middleware):
    """WSGI middleware for Socket.IO.

    This middleware dispatches traffic to a Socket.IO application, and
    optionally forwards regular HTTP traffic to a WSGI application.

    :param socketio_app: The Socket.IO server.
    :param wsgi_app: The WSGI app that receives all other traffic.
    :param socketio_path: The endpoint where the Socket.IO application should
                          be installed. The default value is appropriate for
                          most cases.

    Example usage::

        import socketio
        import eventlet
        from . import wsgi_app

        sio = socketio.Server()
        app = socketio.Middleware(sio, wsgi_app)
        eventlet.wsgi.server(eventlet.listen(('', 8000)), app)
    """
    def __init__(self, socketio_app, wsgi_app=None, socketio_path='socket.io'):
        super(Middleware, self).__init__(socketio_app, wsgi_app, socketio_path)
